#region Copyright Syncfusion Inc. 2001 - 2016
// Copyright Syncfusion Inc. 2001 - 2016. All rights reserved.
// Use of this code is subject to the terms of our license.
// A copy of the current license can be obtained at any time by e-mailing
// licensing@syncfusion.com. Any infringement will be prosecuted under
// applicable laws. 
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Interactivity;
using Syncfusion.Windows.Controls.Gantt;
using Syncfusion.Windows.Controls.Grid;
using System.Windows;
using System.Windows.Media.Imaging;
using System.Windows.Media;
using Syncfusion.Windows.GridCommon;

namespace CustomizedTable
{
    class GridCustomizationBehavior : Behavior<GanttControl>
    {
        /// <summary>
        /// Called after the behavior is attached to an AssociatedObject.
        /// </summary>
        /// <remarks>Override this to hook up functionality to the AssociatedObject.</remarks>
        protected override void OnAttached()
        {
            AssociatedObject.Loaded += new System.Windows.RoutedEventHandler(AssociatedObject_Loaded);

        }

        /// <summary>
        /// Handles the Loaded event of the AssociatedObject control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.Windows.RoutedEventArgs"/> instance containing the event data.</param>
        void AssociatedObject_Loaded(object sender, System.Windows.RoutedEventArgs e)
        {
            this.AssociatedObject.GanttGrid.InternalGrid.UnboundRowPosition = Position.Bottom;

            this.AssociatedObject.GanttGrid.InternalGrid.UnboundRowsCount = 3;

            //To get a constant rows at the footer position of the Grid Column
            this.AssociatedObject.GanttGrid.InternalGrid.FooterRows = 3;

            this.AssociatedObject.GanttGrid.InternalGrid.QueryCellInfo += InternalGrid_QueryCellInfo;

            this.AssociatedObject.GanttGrid.InternalGrid.QueryCoveredRange += InternalGrid_QueryCoveredRange;

            //Need to refresh the rows for layout changes in Grid
            this.AssociatedObject.GanttGrid.InternalGrid.ResetDisplay();
        }

        void InternalGrid_QueryCoveredRange(object sender, GridQueryCoveredRangeEventArgs e)

        {
            var rowcolIndex = e.CellRowColumnIndex;
            if (rowcolIndex.ColumnIndex >= 1)
            {
                var unboundPos = this.AssociatedObject.GanttGrid.InternalGrid.ResolveIndexToUnboundRowPosition(rowcolIndex.RowIndex);
                if (unboundPos >= 0 && unboundPos < this.AssociatedObject.GanttGrid.InternalGrid.UnboundRowsCount)
                {
                    e.Range = new Syncfusion.Windows.Controls.Cells.CoveredCellInfo(rowcolIndex.RowIndex, 1, rowcolIndex.RowIndex, AssociatedObject.GanttGrid.Model.ColumnCount - 1);
                    e.Handled = true;
                }
            }
        }

        void InternalGrid_QueryCellInfo(object sender, GridQueryCellInfoEventArgs e)

        {

            if (e.Style.Tag != null && e.Style.Tag.Equals("UnboundRow") && e.Style.ColumnIndex == 1)

            {
                var unboundPos = this.AssociatedObject.GanttGrid.InternalGrid.ResolveIndexToUnboundRowPosition(e.Style.RowIndex);

                if (unboundPos == 0)
                    e.Style.CellValue = "_attivi : " + 22;

                else if (unboundPos == 1)
                    e.Style.CellValue = "_magazzino : " + 3;

                else if (unboundPos == 2)
                    e.Style.CellValue = "_archivio: " + 3;

                e.Style.Background = new SolidColorBrush(GridUtil.GetXamlConvertedValue<Color>("#FFA9C1DE"));
                e.Style.Foreground = new SolidColorBrush(GridUtil.GetXamlConvertedValue<Color>("#FF1E395B"));
                e.Style.ReadOnly = true;

            }

        }

        /// <summary>
        /// Called when the behavior is being detached from its AssociatedObject, but before it has actually occurred.
        /// </summary>
        /// <remarks>Override this to unhook functionality from the AssociatedObject.</remarks>
        protected override void OnDetaching()
        {
            AssociatedObject.Loaded -= new System.Windows.RoutedEventHandler(AssociatedObject_Loaded);
        }
    }
}
